Text archives Help
- From: sparker@sci.utah.edu
- To: manta@sci.utah.edu
- Subject: [MANTA] r754 - in trunk: . Engine/Control Engine/Display Engine/IdleModes Interface Model/Groups Model/Materials Model/Readers Model/Readers/BART Model/Textures Readers StandAlone SwigInterface UserInterface fox scenes
- Date: Thu, 8 Dec 2005 14:28:55 -0700 (MST)
Author: sparker
Date: Thu Dec 8 14:28:52 2005
New Revision: 754
Added:
trunk/Interface/MantaInterface.cc
- copied, changed from r751, trunk/Interface/RTRTInterface.cc
trunk/Interface/MantaInterface.h
- copied, changed from r752, trunk/Interface/RTRTInterface.h
trunk/Model/Readers/BART/
- copied from r751, trunk/Readers/BART/
trunk/Model/Readers/BART/README_src.txt
- copied unchanged from r753, trunk/Readers/BART/README_src.txt
trunk/Model/Readers/BART/animation.c
- copied unchanged from r753, trunk/Readers/BART/animation.c
trunk/Model/Readers/BART/animation.h
- copied unchanged from r753, trunk/Readers/BART/animation.h
trunk/Model/Readers/BART/kbsplpos.c
- copied unchanged from r753, trunk/Readers/BART/kbsplpos.c
trunk/Model/Readers/BART/kbsplpos.h
- copied unchanged from r753, trunk/Readers/BART/kbsplpos.h
trunk/Model/Readers/BART/kbsplrot.c
- copied unchanged from r753, trunk/Readers/BART/kbsplrot.c
trunk/Model/Readers/BART/kbsplrot.h
- copied unchanged from r753, trunk/Readers/BART/kbsplrot.h
trunk/Model/Readers/BART/parse.cc
- copied unchanged from r753, trunk/Readers/BART/parse.cc
trunk/Model/Readers/BART/parse.h
- copied unchanged from r753, trunk/Readers/BART/parse.h
trunk/Model/Readers/BART/quat.c
- copied unchanged from r753, trunk/Readers/BART/quat.c
trunk/Model/Readers/BART/quat.h
- copied unchanged from r753, trunk/Readers/BART/quat.h
trunk/Model/Readers/BART/smalltest.aff
- copied unchanged from r753, trunk/Readers/BART/smalltest.aff
trunk/Model/Readers/BART/sub.mk
- copied unchanged from r753, trunk/Readers/BART/sub.mk
trunk/Model/Readers/BART/texture.c
- copied unchanged from r753, trunk/Readers/BART/texture.c
trunk/Model/Readers/BART/texture.h
- copied unchanged from r753, trunk/Readers/BART/texture.h
Removed:
trunk/Interface/RTRTInterface.cc
trunk/Interface/RTRTInterface.h
trunk/Readers/
Modified:
trunk/CMakeLists.txt
trunk/Engine/Control/RTRT.cc
trunk/Engine/Control/RTRT.h
trunk/Engine/Control/RTRT_register.cc
trunk/Engine/Display/SHMImageDisplay.h
trunk/Engine/IdleModes/ZoomIdleMode.cc
trunk/Interface/CMakeLists.txt
trunk/Interface/Context.h
trunk/Interface/Transaction.h
trunk/Model/Groups/VolumeGrid.h
trunk/Model/Materials/Lambertian.h
trunk/Model/Readers/CMakeLists.txt
trunk/Model/Textures/ImageTexture.cc
trunk/Model/Textures/ImageTexture.h
trunk/StandAlone/manta.cc
trunk/SwigInterface/manta.h
trunk/UserInterface/AutomatorUI.cc
trunk/UserInterface/AutomatorUI.h
trunk/UserInterface/CameraPathAutomator.cc
trunk/UserInterface/CameraPathAutomator.h
trunk/UserInterface/NullUI.h
trunk/UserInterface/PromptUI.cc
trunk/UserInterface/PromptUI.h
trunk/UserInterface/XWindowUI.cc
trunk/UserInterface/XWindowUI.h
trunk/fox/FMantaImageFrame.h
trunk/fox/FMantaKdExplorer.h
trunk/fox/FMantaNavigator.h
trunk/fox/FMantaQuakeNav.h
trunk/fox/FMantaRecorder.h
trunk/fox/FMantaWidgets.h
trunk/fox/FMantaWindow.h
trunk/scenes/0.cc
trunk/scenes/ParticleBVHTest.cc
trunk/scenes/acceltest.cc
trunk/scenes/cube.cc
trunk/scenes/objviewer.cc
trunk/scenes/primtest.cc
trunk/scenes/volume.cc
Log:
Fixes to scenes. Everything compiles except volume, objviewer, boeing777
Changed RTRTInterface to MantaInterface
Modified: trunk/CMakeLists.txt
==============================================================================
--- trunk/CMakeLists.txt (original)
+++ trunk/CMakeLists.txt Thu Dec 8 14:28:52 2005
@@ -160,7 +160,6 @@
UserInterface
Engine
StandAlone
- Readers
scenes
tests
)
Modified: trunk/Engine/Control/RTRT.cc
==============================================================================
--- trunk/Engine/Control/RTRT.h (original)
+++ trunk/Engine/Control/RTRT.h Thu Dec 8 14:28:52 2005
@@ -2,7 +2,7 @@
#ifndef Manta_Engine_RTRT_h
#define Manta_Engine_RTRT_h
-#include <Interface/RTRTInterface.h>
+#include <Interface/MantaInterface.h>
#include <Interface/FrameState.h>
#include <Interface/Parameters.h>
#include <Core/Thread/AtomicCounter.h>
@@ -27,13 +27,13 @@
namespace Manta {
using namespace std;
- RTRTInterface* createRTRT();
+ MantaInterface* createRTRT();
class Camera;
class Image;
class Scene;
- class RTRT : public RTRTInterface {
+ class RTRT : public MantaInterface {
public:
RTRT();
~RTRT();
@@ -112,7 +112,7 @@
virtual void registerSetupCallback(SetupCallback*);
virtual void registerSerialAnimationCallback(CallbackBase_3Data<int,
int, bool&>*);
virtual void registerParallelAnimationCallback(CallbackBase_3Data<int,
int, bool&>*);
- virtual void registerTerminationCallback( CallbackBase_1Data<
RTRTInterface *> *);
+ virtual void registerTerminationCallback( CallbackBase_1Data<
MantaInterface *> *);
// Control of time/animation
virtual void setTimeMode(TimeMode tm, double rate);
@@ -205,7 +205,7 @@
ACallbackMapType serialAnimationCallbacks;
vector<SetupCallback*> setupCallbacks;
- typedef vector<CallbackBase_1Data<RTRTInterface *>*> TCallbackMapType;
+ typedef vector<CallbackBase_1Data<MantaInterface *>*> TCallbackMapType;
TCallbackMapType terminationCallbacks;
Modified: trunk/Engine/Control/RTRT_register.cc
==============================================================================
--- trunk/Engine/Control/RTRT_register.cc (original)
+++ trunk/Engine/Control/RTRT_register.cc Thu Dec 8 14:28:52 2005
@@ -1,4 +1,4 @@
-#include <Interface/RTRTInterface.h>
+#include <Interface/MantaInterface.h>
#include <Engine/Display/NullDisplay.h>
#include <Engine/Display/OpenGLDisplay.h>
#include <Engine/Display/FileDisplay.h>
@@ -41,70 +41,70 @@
namespace Manta {
- void registerKnownComponents(RTRTInterface* rtrt)
+ void registerKnownComponents(MantaInterface* engine)
{
// Register display components
- rtrt->registerComponent("null", &NullDisplay::create);
- rtrt->registerComponent("opengl", &OpenGLDisplay::create);
- rtrt->registerComponent("file", &FileDisplay::create);
+ engine->registerComponent("null", &NullDisplay::create);
+ engine->registerComponent("opengl", &OpenGLDisplay::create);
+ engine->registerComponent("file", &FileDisplay::create);
#ifdef __ia64__
- rtrt->registerComponent("mf", &SHMImageDisplay::create);
+ engine->registerComponent("mf", &SHMImageDisplay::create);
#endif
// Register image traversers
- rtrt->registerComponent("null", &NullImageTraverser::create);
- rtrt->registerComponent("tiled", &TiledImageTraverser::create);
- rtrt->registerComponent("dissolve", &DissolveImageTraverser::create);
- rtrt->registerComponent("dissolvetiled",
&DissolveTiledImageTraverser::create);
+ engine->registerComponent("null", &NullImageTraverser::create);
+ engine->registerComponent("tiled", &TiledImageTraverser::create);
+ engine->registerComponent("dissolve", &DissolveImageTraverser::create);
+ engine->registerComponent("dissolvetiled",
&DissolveTiledImageTraverser::create);
// Register image types
- rtrt->registerComponent("null", &NullImage::create);
- rtrt->registerComponent("rgba8", &SimpleImage<RGBA8Pixel>::create);
- rtrt->registerComponent("rgb8", &SimpleImage<RGB8Pixel>::create);
- rtrt->registerComponent("rgbafloat",
+ engine->registerComponent("null", &NullImage::create);
+ engine->registerComponent("rgba8", &SimpleImage<RGBA8Pixel>::create);
+ engine->registerComponent("rgb8", &SimpleImage<RGB8Pixel>::create);
+ engine->registerComponent("rgbafloat",
&SimpleImage<RGBAfloatPixel>::create);
- rtrt->registerComponent("rgbfloat",
+ engine->registerComponent("rgbfloat",
&SimpleImage<RGBfloatPixel>::create);
// Register load balancers
- rtrt->registerComponent("cyclic", &CyclicLoadBalancer::create);
- rtrt->registerComponent("simple", &SimpleLoadBalancer::create);
- rtrt->registerComponent("workqueue", &WQLoadBalancer::create);
+ engine->registerComponent("cyclic", &CyclicLoadBalancer::create);
+ engine->registerComponent("simple", &SimpleLoadBalancer::create);
+ engine->registerComponent("workqueue", &WQLoadBalancer::create);
// Register pixel samplers
- rtrt->registerComponent("null", &NullSampler::create);
- rtrt->registerComponent("singlesample", &SingleSampler::create);
- rtrt->registerComponent("jittersample", &JitterSampler::create);
+ engine->registerComponent("null", &NullSampler::create);
+ engine->registerComponent("singlesample", &SingleSampler::create);
+ engine->registerComponent("jittersample", &JitterSampler::create);
// Register renderers
- rtrt->registerComponent("null", &NullRenderer::create);
- rtrt->registerComponent("moire", &Moire::create);
- rtrt->registerComponent("raytracer", &Raytracer::create);
+ engine->registerComponent("null", &NullRenderer::create);
+ engine->registerComponent("moire", &Moire::create);
+ engine->registerComponent("raytracer", &Raytracer::create);
// Register cameras
- rtrt->registerComponent("environment", &EnvironmentCamera::create);
- rtrt->registerComponent("pinhole", &PinholeCamera::create);
- rtrt->registerComponent("stereo", &StereoPinholeCamera::create);
- rtrt->registerComponent("orthogonal", &OrthogonalCamera::create);
- rtrt->registerComponent("fisheye", &FisheyeCamera::create);
+ engine->registerComponent("environment", &EnvironmentCamera::create);
+ engine->registerComponent("pinhole", &PinholeCamera::create);
+ engine->registerComponent("stereo", &StereoPinholeCamera::create);
+ engine->registerComponent("orthogonal", &OrthogonalCamera::create);
+ engine->registerComponent("fisheye", &FisheyeCamera::create);
// Register shadow algorithms
- rtrt->registerComponent("noshadows", &NoShadows::create);
- rtrt->registerComponent("hard", &HardShadows::create);
- rtrt->registerComponent("beam", &BeamShadows::create);
+ engine->registerComponent("noshadows", &NoShadows::create);
+ engine->registerComponent("hard", &HardShadows::create);
+ engine->registerComponent("beam", &BeamShadows::create);
// Idle modes
- rtrt->registerComponent("zoom", &ZoomIdleMode::create);
+ engine->registerComponent("zoom", &ZoomIdleMode::create);
// Register user interfaces
- rtrt->registerComponent("null", &NullUI::create);
- rtrt->registerComponent("prompt", &PromptUI::create);
- rtrt->registerComponent("X", &XWindowUI::create);
- rtrt->registerComponent("camerapath", &CameraPathAutomator::create);
+ engine->registerComponent("null", &NullUI::create);
+ engine->registerComponent("prompt", &PromptUI::create);
+ engine->registerComponent("X", &XWindowUI::create);
+ engine->registerComponent("camerapath", &CameraPathAutomator::create);
// Register groups
- rtrt->registerObject("group", &Group::create);
- rtrt->registerObject("grid", &GriddedGroup::create);
- rtrt->registerObject("bvh", &BVH::create);
+ engine->registerObject("group", &Group::create);
+ engine->registerObject("grid", &GriddedGroup::create);
+ engine->registerObject("bvh", &BVH::create);
}
}
Modified: trunk/Engine/Display/SHMImageDisplay.h
==============================================================================
--- trunk/Engine/Display/SHMImageDisplay.h (original)
+++ trunk/Engine/Display/SHMImageDisplay.h Thu Dec 8 14:28:52 2005
@@ -65,7 +65,7 @@
SHMImageDisplay( int shm_key_ ) : shm_key( shm_key_ ), stream_data( 0 )
{ };
~SHMImageDisplay();
- // RTRT_register creator function.
+ // Manta_register creator function.
static ImageDisplay *create( const vector<string> &args ) { return new
SHMImageDisplay( args ); };
// Manta ImageDisplay interface.
Modified: trunk/Engine/IdleModes/ZoomIdleMode.cc
==============================================================================
--- trunk/Engine/IdleModes/ZoomIdleMode.cc (original)
+++ trunk/Engine/IdleModes/ZoomIdleMode.cc Thu Dec 8 14:28:52 2005
@@ -1,7 +1,7 @@
#include <Engine/IdleModes/ZoomIdleMode.h>
#include <Interface/Context.h>
-#include <Interface/RTRTInterface.h>
+#include <Interface/MantaInterface.h>
#include <Core/Math/MinMax.h>
using namespace Manta;
Modified: trunk/Interface/CMakeLists.txt
==============================================================================
--- trunk/Interface/CMakeLists.txt (original)
+++ trunk/Interface/CMakeLists.txt Thu Dec 8 14:28:52 2005
@@ -23,6 +23,8 @@
LightSet.cc
LoadBalancer.h
LoadBalancer.cc
+ MantaInterface.h
+ MantaInterface.cc
Material.h
Material.cc
Object.h
@@ -35,8 +37,6 @@
Renderer.h
Renderer.cc
RenderParameters.h
- RTRTInterface.h
- RTRTInterface.cc
SetupCallback.h
SetupCallback.cc
Scene.h
Modified: trunk/Interface/Context.h
==============================================================================
--- trunk/Interface/Context.h (original)
+++ trunk/Interface/Context.h Thu Dec 8 14:28:52 2005
@@ -10,7 +10,7 @@
class PixelSampler;
class ReadContext;
class Renderer;
- class RTRTInterface;
+ class MantaInterface;
class Scene;
class ShadowAlgorithm;
class XWindow;
@@ -18,11 +18,11 @@
class ReadContext {
public:
- ReadContext(RTRTInterface* rtrt_int)
+ ReadContext(MantaInterface* rtrt_int)
: rtrt_int(rtrt_int)
{
}
- mutable RTRTInterface* rtrt_int;
+ mutable MantaInterface* rtrt_int;
private:
ReadContext(const ReadContext&);
@@ -39,7 +39,7 @@
class SetupContext {
public:
- SetupContext(RTRTInterface* rtrt_int,
+ SetupContext(MantaInterface* rtrt_int,
int channelIndex, int numChannels, int proc, int numProcs,
bool stereo, int xres, int yres,
LoadBalancer* loadBalancer, PixelSampler* pixelSampler,
@@ -56,7 +56,7 @@
{
init();
}
- SetupContext(RTRTInterface* rtrt_int, int numChannels,
+ SetupContext(MantaInterface* rtrt_int, int numChannels,
int proc, int numProcs,
LoadBalancer* loadBalancer, PixelSampler* pixelSampler,
Renderer* renderer)
@@ -73,7 +73,7 @@
maxPipelineDepth = 1000;
masterWindow = 0;
}
- RTRTInterface* rtrt_int;
+ MantaInterface* rtrt_int;
int channelIndex;
int numChannels;
int proc;
@@ -146,7 +146,7 @@
};
class RenderContext {
public:
- RenderContext(RTRTInterface* rtrt_int,
+ RenderContext(MantaInterface* rtrt_int,
int channelIndex, int proc, int numProcs,
const FrameState* frameState,
LoadBalancer* loadBalancer, PixelSampler* pixelSampler,
@@ -162,7 +162,7 @@
storage_allocator( storage_allocator_ )
{
}
- RTRTInterface* rtrt_int;
+ MantaInterface* rtrt_int;
int channelIndex;
int proc;
int numProcs;
@@ -183,7 +183,7 @@
class PreprocessContext {
public:
PreprocessContext() { }; // Lights are dynamic now. This
context isn't needed.
- PreprocessContext(RTRTInterface* /*rtrt_int*/, LightSet* globalLights)
+ PreprocessContext(MantaInterface* /*rtrt_int*/, LightSet* globalLights)
: globalLights(globalLights)
{
}
Copied: trunk/Interface/MantaInterface.cc (from r751,
trunk/Interface/RTRTInterface.cc)
==============================================================================
--- trunk/Interface/RTRTInterface.cc (original)
+++ trunk/Interface/MantaInterface.cc Thu Dec 8 14:28:52 2005
@@ -1,13 +1,13 @@
-#include <Interface/RTRTInterface.h>
+#include <Interface/MantaInterface.h>
using namespace Manta;
-RTRTInterface::RTRTInterface()
+MantaInterface::MantaInterface()
{
}
-RTRTInterface::~RTRTInterface()
+MantaInterface::~MantaInterface()
{
}
Copied: trunk/Interface/MantaInterface.h (from r752,
trunk/Interface/RTRTInterface.h)
==============================================================================
--- trunk/Interface/RTRTInterface.h (original)
+++ trunk/Interface/MantaInterface.h Thu Dec 8 14:28:52 2005
@@ -1,6 +1,6 @@
-#ifndef Manta_Interface_RTRTInterface_H
-#define Manta_Interface_RTRTInterface_H
+#ifndef Manta_Interface_MantaInterface_H
+#define Manta_Interface_MantaInterface_H
#include <Interface/Callback.h>
#include <Interface/Transaction.h>
@@ -27,10 +27,10 @@
class ShadowAlgorithm;
class UserInterface;
- class RTRTInterface {
+ class MantaInterface {
public:
- virtual ~RTRTInterface();
+ virtual ~MantaInterface();
typedef vector<string> listType;
@@ -125,7 +125,7 @@
virtual void registerSetupCallback(SetupCallback*) = 0;
virtual void registerSerialAnimationCallback(CallbackBase_3Data<int,
int, bool&>*) = 0;
virtual void registerParallelAnimationCallback(CallbackBase_3Data<int,
int, bool&>*) = 0;
- virtual void registerTerminationCallback( CallbackBase_1Data<
RTRTInterface *> *) = 0;
+ virtual void registerTerminationCallback( CallbackBase_1Data<
MantaInterface *> *) = 0;
// Settings
enum TimeMode {
@@ -146,7 +146,7 @@
// User Interfaces
typedef UserInterface* (*UserInterfaceCreator)(const vector<string>&
args,
- RTRTInterface
*rtrt_interface);
+ MantaInterface
*rtrt_interface);
virtual UserInterface* createUserInterface(const string& spec) = 0;
virtual void registerComponent(const string& name, UserInterfaceCreator
creator) = 0;
virtual listType listUserInterfaces() const = 0;
@@ -169,13 +169,13 @@
}
protected:
- RTRTInterface();
+ MantaInterface();
private:
- RTRTInterface(const RTRTInterface&);
- RTRTInterface& operator=(const RTRTInterface&);
+ MantaInterface(const MantaInterface&);
+ MantaInterface& operator=(const MantaInterface&);
};
- RTRTInterface* createRTRT();
+ MantaInterface* createManta();
}
#endif
Modified: trunk/Interface/Transaction.h
==============================================================================
--- trunk/Interface/Transaction.h (original)
+++ trunk/Interface/Transaction.h Thu Dec 8 14:28:52 2005
@@ -8,7 +8,7 @@
#include <typeinfo>
namespace Manta {
- class RTRTInterface;
+ class MantaInterface;
class TransactionBase {
public:
Modified: trunk/Model/Groups/VolumeGrid.h
==============================================================================
--- trunk/Model/Groups/VolumeGrid.h (original)
+++ trunk/Model/Groups/VolumeGrid.h Thu Dec 8 14:28:52 2005
@@ -7,7 +7,6 @@
#include <Model/Intersections/AxisAlignedBox.h>
#include <Interface/RayPacket.h>
-#include <Model/Materials/LambertianAlt.h>
#include <Model/Materials/CopyColorMaterial.h>
#include <SCIRun/Core/Math/MiscMath.h>
#include <SCIRun/Core/Math/MinMax.h>
Modified: trunk/Model/Materials/Lambertian.h
==============================================================================
--- trunk/Model/Materials/Lambertian.h (original)
+++ trunk/Model/Materials/Lambertian.h Thu Dec 8 14:28:52 2005
@@ -13,7 +13,7 @@
public:
Lambertian(const Color& color);
Lambertian(const Texture<Color>* colorfn);
- Lambertian() { };
+ Lambertian() { };
virtual ~Lambertian();
virtual void shade(const RenderContext& context, RayPacket& rays) const;
Modified: trunk/Model/Readers/CMakeLists.txt
==============================================================================
--- trunk/Model/Readers/CMakeLists.txt (original)
+++ trunk/Model/Readers/CMakeLists.txt Thu Dec 8 14:28:52 2005
@@ -1,9 +1,11 @@
SET (Manta_Readers_SRCS
+ Readers/PlyReader.cc
+ Readers/rply/rply.c
Readers/glm/glm.h
Readers/glm/glm.cc)
# Apple places malloc.h in /usr/include/malloc/malloc.h
IF (APPLE)
INCLUDE_DIRECTORIES(/usr/include/malloc/)
-ENDIF (APPLE)
\ No newline at end of file
+ENDIF (APPLE)
Modified: trunk/Model/Textures/ImageTexture.cc
==============================================================================
--- trunk/Model/Textures/ImageTexture.cc (original)
+++ trunk/Model/Textures/ImageTexture.cc Thu Dec 8 14:28:52 2005
@@ -1,95 +1,3 @@
-<<<<<<< .working
-
-#include <Model/Textures/ImageTexture.h>
-#include <Interface/RayPacket.h>
-#include <Core/Geometry/PointVector.h>
-#include <Core/Math/Noise.h>
-#include <Core/Math/MiscMath.h>
-#include <Core/Exceptions/InternalError.h>
-#include <Image/NullImage.h>
-#include <Image/Pixel.h>
-#include <Image/SimpleImage.h>
-
-namespace Manta {
-
- ImageTexture::ImageTexture(
- Image *img,
- double x_scale,
- double y_scale )
- : img( img ),
- x_scale( x_scale ),
- y_scale( y_scale )
- {
- }
-
- ImageTexture::~ImageTexture()
- {
- delete img;
- }
-
- void ImageTexture::mapValues(
- RenderContext const &context,
- RayPacket &rays,
- Color results[] ) const
- {
- bool stereo;
- int xres, yres;
- img->getResolution( stereo, xres, yres );
- rays.computeTextureCoordinates3( context );
- if ( typeid( *img ) == typeid( SimpleImage< RGB8Pixel > ) ) {
- const SimpleImage< RGB8Pixel > *si = dynamic_cast< const SimpleImage<
RGB8Pixel > * >( img );
- RGB8Pixel const *buffer = si->getRaw( 0 );
- for( int i = 0; i < rays.getSize(); i++ ) {
- RayPacket::Element &e = rays.get( i );
- double x = SCIRun::Fraction( e.texCoords.x() * x_scale ) * xres;
- double y = SCIRun::Fraction( e.texCoords.y() * y_scale ) * yres;
- int left = static_cast< int >( x );
- int bottom = static_cast< int >( y );
- int right = ( left + 1 ) == xres ? 0 : left + 1;
- int top = ( bottom + 1 ) == yres ? 0 : bottom + 1;
- RGB8Pixel const *upper_left = buffer + top * xres + left;
- Color upper_left_color = Color( RGB( upper_left->r / 255.0,
upper_left->g / 255.0, upper_left->b / 255.0 ) );
- RGB8Pixel const *upper_right = buffer + top * xres + right;
- Color upper_right_color = Color( RGB( upper_right->r / 255.0,
upper_right->g / 255.0, upper_right->b / 255.0 ) );
- RGB8Pixel const *lower_left = buffer + bottom * xres + left;
- Color lower_left_color = Color( RGB( lower_left->r / 255.0,
lower_left->g / 255.0, lower_left->b / 255.0 ) );
- RGB8Pixel const *lower_right = buffer + bottom * xres + right;
- Color lower_right_color = Color( RGB( lower_right->r / 255.0,
lower_right->g / 255.0, lower_right->b / 255.0 ) );
- results[ i ] = SCIRun::Interpolate( SCIRun::Interpolate(
lower_left_color, lower_right_color, x - left ),
- SCIRun::Interpolate(
upper_left_color, upper_right_color, x - left ),
- y - bottom );
- }
- } else if ( typeid( *img ) == typeid( SimpleImage< RGBA8Pixel > ) ) {
- const SimpleImage< RGBA8Pixel > *si = dynamic_cast< const SimpleImage<
RGBA8Pixel > * >( img );
- RGBA8Pixel const *buffer = si->getRaw( 0 );
- for( int i = 0; i < rays.getSize(); i++ ) {
- RayPacket::Element &e = rays.get( i );
- double x = SCIRun::Fraction( e.texCoords.x() * x_scale ) * xres;
- double y = SCIRun::Fraction( e.texCoords.y() * y_scale ) * yres;
- int left = static_cast< int >( x );
- int bottom = static_cast< int >( y );
- int right = ( left + 1 ) == xres ? 0 : left + 1;
- int top = ( bottom + 1 ) == yres ? 0 : bottom + 1;
- RGBA8Pixel const *upper_left = buffer + top * xres + left;
- Color upper_left_color = Color( RGB( upper_left->r / 255.0,
upper_left->g / 255.0, upper_left->b / 255.0 ) );
- RGBA8Pixel const *upper_right = buffer + top * xres + right;
- Color upper_right_color = Color( RGB( upper_right->r / 255.0,
upper_right->g / 255.0, upper_right->b / 255.0 ) );
- RGBA8Pixel const *lower_left = buffer + bottom * xres + left;
- Color lower_left_color = Color( RGB( lower_left->r / 255.0,
lower_left->g / 255.0, lower_left->b / 255.0 ) );
- RGBA8Pixel const *lower_right = buffer + bottom * xres + right;
- Color lower_right_color = Color( RGB( lower_right->r / 255.0,
lower_right->g / 255.0, lower_right->b / 255.0 ) );
- results[ i ] = SCIRun::Interpolate( SCIRun::Interpolate(
lower_left_color, lower_right_color, x - left ),
- SCIRun::Interpolate(
upper_left_color, upper_right_color, x - left ),
- y - bottom );
- }
- } else {
- throw SCIRun::InternalError("Unknown image type in ImageTexture",
- __FILE__, __LINE__);
- }
- }
-
-}
-=======
/*
For more information, please see:
http://software.sci.utah.edu
@@ -240,4 +148,4 @@
}
} // end namespace Manta
->>>>>>> .merge-right.r751
+
Modified: trunk/Model/Textures/ImageTexture.h
==============================================================================
--- trunk/Model/Textures/ImageTexture.h (original)
+++ trunk/Model/Textures/ImageTexture.h Thu Dec 8 14:28:52 2005
@@ -1,50 +1,3 @@
-<<<<<<< .working
-
-#ifndef Manta_Model_ImageTexture_h
-#define Manta_Model_ImageTexture_h
-
-#include <Interface/Texture.h>
-#include <Core/Color/RGBColor.h>
-#include <MantaTypes.h>
-
-namespace Manta {
- class RayPacket;
- class RenderContext;
- class Image;
- class ImageTexture : public Texture< Color > {
- public:
- /**
- * Note that this material will destroy the image that it's given when
- * destroyed itself.
- */
- ImageTexture(
- Image *img,
- double x_scale,
- double y_scale );
- virtual ~ImageTexture();
- virtual void mapValues(
- RenderContext const &context,
- RayPacket &rays,
- Color results[] ) const;
- private:
- ImageTexture(
- ImageTexture const & );
- ImageTexture& operator=(
- ImageTexture const & );
-
- Image *img;
- double x_scale;
- double y_scale;
- };
-}
-
-#ifdef __GNUG__
-// This should instead be a configure variable...
-#include <Model/Textures/ImageTexture.cc>
-#endif
-
-#endif
-=======
/*
For more information, please see:
http://software.sci.utah.edu
@@ -240,4 +193,3 @@
#endif
#endif // Manta_Model_ImageTexture_h
->>>>>>> .merge-right.r751
Modified: trunk/StandAlone/manta.cc
==============================================================================
--- trunk/StandAlone/manta.cc (original)
+++ trunk/StandAlone/manta.cc Thu Dec 8 14:28:52 2005
@@ -1,5 +1,5 @@
-#include <Interface/RTRTInterface.h>
+#include <Interface/MantaInterface.h>
#include <Core/Color/ColorDB.h>
#include <Core/Util/Args.h>
#include <Interface/Callback.h>
@@ -30,11 +30,11 @@
static Scene* createDefaultScene();
static void
-printList(ostream& out, const RTRTInterface::listType& list, int spaces=0)
+printList(ostream& out, const MantaInterface::listType& list, int spaces=0)
{
for(int i=0;i<spaces;i++)
out << ' ';
- for(RTRTInterface::listType::const_iterator iter = list.begin();
+ for(MantaInterface::listType::const_iterator iter = list.begin();
iter != list.end(); ++iter){
if(iter != list.begin())
out << ", ";
@@ -43,7 +43,7 @@
out << "\n";
}
-static void usage(RTRTInterface* rtrt)
+static void usage(MantaInterface* rtrt)
{
cerr << "Usage: manta [options]\n";
cerr << "Valid options are:\n";
@@ -77,17 +77,17 @@
class BenchHelper {
public:
- BenchHelper(RTRTInterface* rtrt, long numFrames);
+ BenchHelper(MantaInterface* rtrt, long numFrames);
void start(int, int);
void stop(int, int);
private:
- RTRTInterface* rtrt;
+ MantaInterface* rtrt;
double startTime;
long numFrames;
};
-BenchHelper::BenchHelper(RTRTInterface* rtrt, long numFrames)
+BenchHelper::BenchHelper(MantaInterface* rtrt, long numFrames)
: rtrt(rtrt), numFrames(numFrames)
{
}
@@ -120,7 +120,7 @@
args.push_back(argv[i]);
try {
- RTRTInterface* rtrt = createRTRT();
+ MantaInterface* rtrt = createManta();
if(getenv("MANTA_SCENEPATH"))
rtrt->setScenePath(getenv("MANTA_SCENEPATH"));
else
@@ -162,9 +162,9 @@
BenchHelper* b = new BenchHelper(rtrt,
numFrames);
// Ask for two callbacks, one at frame
"warmup", and one at
// frame warmup+numFrames
-
rtrt->addOneShotCallback(RTRTInterface::Absolute, warmup,
+
rtrt->addOneShotCallback(MantaInterface::Absolute, warmup,
Callback::create(b,
&BenchHelper::start));
-
rtrt->addOneShotCallback(RTRTInterface::Absolute, warmup+numFrames,
+
rtrt->addOneShotCallback(MantaInterface::Absolute, warmup+numFrames,
Callback::create(b,
&BenchHelper::stop));
} else if(arg == "-camera"){
string s;
Modified: trunk/SwigInterface/manta.h
==============================================================================
--- trunk/SwigInterface/manta.h (original)
+++ trunk/SwigInterface/manta.h Thu Dec 8 14:28:52 2005
@@ -1,4 +1,4 @@
-#include <Interface/RTRTInterface.h>
+#include <Interface/MantaInterface.h>
#include <Interface/Callback.h>
#include <sgi_stl_warnings_off.h>
@@ -9,9 +9,9 @@
using namespace std;
class PipelineChanger {
- RTRTInterface* rtrt_interface;
+ MantaInterface* rtrt_interface;
public:
- PipelineChanger(RTRTInterface* rtrt_interface):
+ PipelineChanger(MantaInterface* rtrt_interface):
rtrt_interface(rtrt_interface)
{}
@@ -28,13 +28,13 @@
}
void changePixelSampler(string spec) {
- rtrt_interface->addOneShotCallback(RTRTInterface::Relative, 0,
+ rtrt_interface->addOneShotCallback(MantaInterface::Relative, 0,
Callback::create(this,
&PipelineChanger::changePixelSamplerCallback,
spec));
}
void changeResolution(int channel, int new_xres, int new_yres) {
- rtrt_interface->addOneShotCallback(RTRTInterface::Relative, 0,
+ rtrt_interface->addOneShotCallback(MantaInterface::Relative, 0,
Callback::create(this,
&PipelineChanger::changeResolutionCallBack,
channel, new_xres, new_yres));
}
Modified: trunk/UserInterface/AutomatorUI.cc
==============================================================================
--- trunk/UserInterface/AutomatorUI.cc (original)
+++ trunk/UserInterface/AutomatorUI.cc Thu Dec 8 14:28:52 2005
@@ -35,7 +35,7 @@
using namespace Manta;
using namespace SCIRun;
-AutomatorUI::AutomatorUI( RTRTInterface *manta_interface_, int
warmup_frames_, bool is_detached_ ) :
+AutomatorUI::AutomatorUI( MantaInterface *manta_interface_, int
warmup_frames_, bool is_detached_ ) :
manta_interface( manta_interface_ ),
warmup_frames( warmup_frames_ ),
is_detached( is_detached_ ),
@@ -57,7 +57,7 @@
void AutomatorUI::run() {
// Have manta call release_automator after warmup_frames.
- manta_interface->addOneShotCallback( RTRTInterface::Relative,
warmup_frames,
+ manta_interface->addOneShotCallback( MantaInterface::Relative,
warmup_frames,
Callback::create(this,
&AutomatorUI::release_automator) );
do {
@@ -109,7 +109,7 @@
if (this_thread) {
// Have manta call release_automator immediately.
- manta_interface->addOneShotCallback( RTRTInterface::Relative, 0,
+ manta_interface->addOneShotCallback( MantaInterface::Relative, 0,
Callback::create(this,
&AutomatorUI::release_automator) );
}
Modified: trunk/UserInterface/AutomatorUI.h
==============================================================================
--- trunk/UserInterface/AutomatorUI.h (original)
+++ trunk/UserInterface/AutomatorUI.h Thu Dec 8 14:28:52 2005
@@ -29,7 +29,7 @@
#ifndef __AUTOMATOR_UI_H__
#define __AUTOMATOR_UI_H__
-#include <Interface/RTRTInterface.h>
+#include <Interface/MantaInterface.h>
#include <Interface/UserInterface.h>
#include <SCIRun/Core/Thread/Thread.h>
@@ -62,7 +62,7 @@
Semaphore startup_semaphore;
// Interface to communicate with the renderer.
- RTRTInterface *manta_interface;
+ MantaInterface *manta_interface;
// Number of frames to wait before starting.
int warmup_frames;
@@ -79,13 +79,13 @@
CallbackBase_0Data *terminate_callback;
protected:
- inline RTRTInterface *getMantaInterface() { return manta_interface; };
+ inline MantaInterface *getMantaInterface() { return manta_interface; };
public:
enum { AUTOMATOR_EXIT, AUTOMATOR_KEEPALIVE };
// Renderer will release the semaphore after "warmup_frames" have been
rendered
- AutomatorUI( RTRTInterface *manta_interface_, int warmup_frames_ = 0,
bool is_detached_ = true );
+ AutomatorUI( MantaInterface *manta_interface_, int warmup_frames_ = 0,
bool is_detached_ = true );
virtual ~AutomatorUI();
// This method must be implemented by Automator implementations.
Modified: trunk/UserInterface/CameraPathAutomator.cc
==============================================================================
--- trunk/UserInterface/CameraPathAutomator.cc (original)
+++ trunk/UserInterface/CameraPathAutomator.cc Thu Dec 8 14:28:52 2005
@@ -52,7 +52,7 @@
// SETUP SETUP SETUP SETUP SETUP SETUP SETUP SETUP SETUP SETUP SETUP SETUP
SETU
///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
-CameraPathAutomator::CameraPathAutomator( RTRTInterface *manta_interface_,
int channel_, int warmup_frames,
+CameraPathAutomator::CameraPathAutomator( MantaInterface *manta_interface_,
int channel_, int warmup_frames,
Point *eye_, Point *lookat_,
Vector *up_, int total_points_,
Real delta_t_, Real delta_time_ )
:
@@ -81,7 +81,7 @@
-CameraPathAutomator::CameraPathAutomator( RTRTInterface *manta_interface_,
int channel_,
+CameraPathAutomator::CameraPathAutomator( MantaInterface *manta_interface_,
int channel_,
int warmup_frames, const string
&file_name,
Real delta_t_, Real delta_time_ ) :
AutomatorUI( manta_interface_, warmup_frames ),
@@ -246,7 +246,7 @@
delete [] up;
}
-UserInterface *CameraPathAutomator::create( const vector<string> &args,
RTRTInterface *manta_interface_ ) {
+UserInterface *CameraPathAutomator::create( const vector<string> &args,
MantaInterface *manta_interface_ ) {
/////////////////////////////////////////////////////////////////////////////
// Parse args.
Modified: trunk/UserInterface/CameraPathAutomator.h
==============================================================================
--- trunk/UserInterface/CameraPathAutomator.h (original)
+++ trunk/UserInterface/CameraPathAutomator.h Thu Dec 8 14:28:52 2005
@@ -90,16 +90,16 @@
// Loop Behaviors
enum { PATH_STOP, PATH_EXIT, PATH_LOOP, PATH_ABORT };
- CameraPathAutomator( RTRTInterface *manta_interface_, int channel_, int
warmup_, const string &file_name,
+ CameraPathAutomator( MantaInterface *manta_interface_, int channel_, int
warmup_, const string &file_name,
Real delta_t_ = 0.2, Real delta_time_ = 0.2 );
- CameraPathAutomator( RTRTInterface *manta_interface_, int channel_, int
warmup_,
+ CameraPathAutomator( MantaInterface *manta_interface_, int channel_, int
warmup_,
Point *eye_, Point *lookat_, Vector *up_, int
total_points_,
Real delta_t_ = 0.2, Real delta_time_ = 0.2 );
~CameraPathAutomator();
// Create method called by RTRT_register.
- static UserInterface *create( const vector<string> &args, RTRTInterface
*manta_interface_ );
+ static UserInterface *create( const vector<string> &args, MantaInterface
*manta_interface_ );
// Implementation of the interpolator.
virtual void run_automator();
Modified: trunk/UserInterface/NullUI.h
==============================================================================
--- trunk/UserInterface/NullUI.h (original)
+++ trunk/UserInterface/NullUI.h Thu Dec 8 14:28:52 2005
@@ -14,7 +14,7 @@
namespace Manta {
- class RTRTInterface;
+ class MantaInterface;
// This class implements a null user interface which should be used
for
// benchmarking.
@@ -26,7 +26,7 @@
// Call this function when you want the User interface to startup
virtual void startup() { /* Does nothing. */ };
- static UserInterface* create(const vector<string>& args,
RTRTInterface *rtrt_int) {
+ static UserInterface* create(const vector<string>& args,
MantaInterface *rtrt_int) {
return new NullUI();
}
};
Modified: trunk/UserInterface/PromptUI.cc
==============================================================================
--- trunk/UserInterface/PromptUI.cc (original)
+++ trunk/UserInterface/PromptUI.cc Thu Dec 8 14:28:52 2005
@@ -29,7 +29,7 @@
#include <UserInterface/PromptUI.h>
#include <UserInterface/AutomatorUI.h>
-#include <Interface/RTRTInterface.h>
+#include <Interface/MantaInterface.h>
#include <Interface/Camera.h>
#include <Interface/ShadowAlgorithm.h>
#include <Core/Util/Args.h>
@@ -55,12 +55,12 @@
///////////////////////////////////////////////////////////////////////////////
UserInterface* PromptUI::create(const vector<string>& args,
- RTRTInterface *manta_interface_) {
+ MantaInterface *manta_interface_) {
return new PromptUI( args, manta_interface_ );
}
-PromptUI::PromptUI(const vector<string>& args, RTRTInterface
*manta_interface_) :
+PromptUI::PromptUI(const vector<string>& args, MantaInterface
*manta_interface_) :
manta_interface( manta_interface_ ),
current_channel( 0 )
{
@@ -309,12 +309,12 @@
}
// This method prints a list of options.
-void PromptUI::printList( ostream& out, const RTRTInterface::listType& list,
int spaces ) {
+void PromptUI::printList( ostream& out, const MantaInterface::listType&
list, int spaces ) {
for(int i=0;i<spaces;i++)
out << ' ';
- for(RTRTInterface::listType::const_iterator iter = list.begin();
+ for(MantaInterface::listType::const_iterator iter = list.begin();
iter != list.end(); ++iter){
if(iter != list.begin())
out << ", ";
Modified: trunk/UserInterface/PromptUI.h
==============================================================================
--- trunk/UserInterface/PromptUI.h (original)
+++ trunk/UserInterface/PromptUI.h Thu Dec 8 14:28:52 2005
@@ -29,7 +29,7 @@
#ifndef RTRT_PromptUI_h
#define RTRT_PromptUI_h
-#include <Interface/RTRTInterface.h>
+#include <Interface/MantaInterface.h>
#include <Interface/UserInterface.h>
#include <Core/Thread/Runnable.h>
@@ -41,7 +41,7 @@
namespace Manta {
using namespace std;
- class RTRTInterface;
+ class MantaInterface;
/////////////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////////
@@ -59,14 +59,14 @@
/////////////////////////////////////////////////////////////////////////////
class PromptUI: public UserInterface, public SCIRun::Runnable {
protected:
- RTRTInterface *manta_interface;
+ MantaInterface *manta_interface;
// Channel that the ui is operating on.
int current_channel;
// Helper methods.
void printHelp();
- void printList( ostream& out, const RTRTInterface::listType& list, int
spaces=0 );
+ void printList( ostream& out, const MantaInterface::listType& list, int
spaces=0 );
void processCommand( const string &input_line );
@@ -77,7 +77,7 @@
void automatorComplete();
public:
- PromptUI(const vector<string>& args, RTRTInterface *rtrt_int);
+ PromptUI(const vector<string>& args, MantaInterface *rtrt_int);
virtual ~PromptUI();
// UserInterface method.
@@ -87,7 +87,7 @@
virtual void run();
static UserInterface* create(const vector<string>& args,
- RTRTInterface *manta_interface_ );
+ MantaInterface *manta_interface_ );
private:
PromptUI(const PromptUI&);
Modified: trunk/UserInterface/XWindowUI.cc
==============================================================================
--- trunk/UserInterface/XWindowUI.cc (original)
+++ trunk/UserInterface/XWindowUI.cc Thu Dec 8 14:28:52 2005
@@ -2,7 +2,7 @@
#include <Core/Util/Args.h>
#include <Interface/Camera.h>
#include <Interface/Context.h>
-#include <Interface/RTRTInterface.h>
+#include <Interface/MantaInterface.h>
#include <Interface/Transaction.h>
#include <Interface/XWindow.h>
#include <Interface/Scene.h>
@@ -48,7 +48,7 @@
using SCIRun::Thread;
UserInterface* XWindowUI::create(const vector<string>& args,
- RTRTInterface *rtrt_interface)
+ MantaInterface *rtrt_interface)
{
UserInterface *newUI = new XWindowUI(args, rtrt_interface);
return newUI;
@@ -64,7 +64,7 @@
ui->removeConnection(fd);
}
-XWindowUI::XWindowUI(const vector<string>& /*args*/, RTRTInterface
*rtrt_interface)
+XWindowUI::XWindowUI(const vector<string>& /*args*/, MantaInterface
*rtrt_interface)
: rtrt_interface(rtrt_interface), xlock("XWindowUI display lock"),
xsema("XWindowUI semaphore", 0)
{
@@ -733,7 +733,7 @@
int new_yres = e.xconfigure.height;
XWindow* window = windows[channel];
if(new_xres != window->xres || new_yres != window->yres)
- rtrt_interface->addOneShotCallback(RTRTInterface::Relative, 0,
+ rtrt_interface->addOneShotCallback(MantaInterface::Relative, 0,
Callback::create(this,
&XWindowUI::changeResolution,
channel, new_xres, new_yres));
} // case ConfigureNotify
Modified: trunk/UserInterface/XWindowUI.h
==============================================================================
--- trunk/UserInterface/XWindowUI.h (original)
+++ trunk/UserInterface/XWindowUI.h Thu Dec 8 14:28:52 2005
@@ -20,13 +20,13 @@
namespace Manta {
using namespace std;
- class RTRTInterface;
+ class MantaInterface;
class TrackBall;
class XWindow;
class XWindowUI: public UserInterface, public SetupCallback, public
SCIRun::Runnable {
public:
- XWindowUI(const vector<string>& args, RTRTInterface *rtrt_interface);
+ XWindowUI(const vector<string>& args, MantaInterface *rtrt_interface);
virtual ~XWindowUI();
// From UserInterface
@@ -40,7 +40,7 @@
virtual void run();
static UserInterface* create(const vector<string>& args,
- RTRTInterface *rtrt_interface);
+ MantaInterface *rtrt_interface);
void addConnection(int fd);
void removeConnection(int fd);
@@ -83,7 +83,7 @@
Vector projectToSphere(Real x, Real y, Real radius) const;
// This is a pointer to the interface we will use to interact with manta.
- RTRTInterface *rtrt_interface;
+ MantaInterface *rtrt_interface;
vector<XWindow*> windows;
void lock_x();
Modified: trunk/fox/FMantaImageFrame.h
==============================================================================
--- trunk/fox/FMantaImageFrame.h (original)
+++ trunk/fox/FMantaImageFrame.h Thu Dec 8 14:28:52 2005
@@ -4,7 +4,7 @@
#include <fx.h>
#include <fx3d.h>
-#include <Interface/RTRTInterface.h>
+#include <Interface/MantaInterface.h>
#include <Engine/Control/RTRT.h>
#include <fox/FMantaQuakeNav.h>
@@ -23,7 +23,7 @@
FXObject *fox_target;
// Pointer to the Manta interface to send commands.
- RTRTInterface *manta_interface;
+ MantaInterface *manta_interface;
// Manta channel number.
int manta_channel;
@@ -43,7 +43,7 @@
// Constructors.
FMantaImageFrame() : manta_interface( 0 ), navigator( 0 ) {
};
- FMantaImageFrame( FXComposite *p, FXApp *app, FXObject
*target, int width, int height, RTRTInterface *manta_interface_ );
+ FMantaImageFrame( FXComposite *p, FXApp *app, FXObject
*target, int width, int height, MantaInterface *manta_interface_ );
// Fox message handlers for mouse and keyboard.
long onConfigure ( FXObject *sender, FXSelector sel, void
*data );
@@ -52,14 +52,14 @@
long onKeyPress ( FXObject *sender, FXSelector sel, void *data );
// Accessors.
- void setMantaInterface( RTRTInterface *manta_interface_, int
manta_channel_ ) {
+ void setMantaInterface( MantaInterface *manta_interface_, int
manta_channel_ ) {
manta_interface = manta_interface_; manta_channel =
manta_channel_; };
void setNavigator( FMantaNavigator *navigator_ ) { navigator
= navigator_; }
FMantaNavigator *getNavigator() { return navigator;
};
int getMantaChannel() const { return
manta_channel; };
- RTRTInterface *getMantaInterface() { return manta_interface;
};
+ MantaInterface *getMantaInterface() { return manta_interface;
};
int getMantaChannel () { return manta_channel;
};
// Debugging.
Modified: trunk/fox/FMantaKdExplorer.h
==============================================================================
--- trunk/fox/FMantaKdExplorer.h (original)
+++ trunk/fox/FMantaKdExplorer.h Thu Dec 8 14:28:52 2005
@@ -33,7 +33,7 @@
private:
FMantaWindow *manta_window;
- RTRTInterface *manta_interface;
+ MantaInterface *manta_interface;
// Target kdtree.
KDTree *kdtree;
Modified: trunk/fox/FMantaNavigator.h
==============================================================================
--- trunk/fox/FMantaNavigator.h (original)
+++ trunk/fox/FMantaNavigator.h Thu Dec 8 14:28:52 2005
@@ -6,7 +6,7 @@
#include <MantaTypes.h>
#include <Interface/Camera.h>
-#include <Interface/RTRTInterface.h>
+#include <Interface/MantaInterface.h>
namespace fox_manta {
@@ -22,7 +22,7 @@
protected:
// Manta interfaces.
- RTRTInterface *manta_interface;
+ MantaInterface *manta_interface;
int manta_channel;
public:
@@ -35,10 +35,10 @@
virtual void setCoordSystemUp( int up ) { coord_system = up; };
virtual int getCoordSystemUp() const { return coord_system; };
- void setMantaInterface( RTRTInterface *manta_interface_ ) {
manta_interface = manta_interface_; };
+ void setMantaInterface( MantaInterface *manta_interface_ ) {
manta_interface = manta_interface_; };
void setMantaChannel ( int manta_channel_ ) { manta_channel
= manta_channel_; };
- RTRTInterface *getMantaInterface() { return manta_interface;
};
+ MantaInterface *getMantaInterface() { return manta_interface;
};
int getMantaChannel() { return manta_channel;
};
// Virtual interface.
Modified: trunk/fox/FMantaQuakeNav.h
==============================================================================
--- trunk/fox/FMantaQuakeNav.h (original)
+++ trunk/fox/FMantaQuakeNav.h Thu Dec 8 14:28:52 2005
@@ -6,7 +6,7 @@
#include <MantaTypes.h>
#include <Interface/Camera.h>
-#include <Interface/RTRTInterface.h>
+#include <Interface/MantaInterface.h>
#include <fox/FMantaNavigator.h>
Modified: trunk/fox/FMantaRecorder.h
==============================================================================
--- trunk/fox/FMantaRecorder.h (original)
+++ trunk/fox/FMantaRecorder.h Thu Dec 8 14:28:52 2005
@@ -36,7 +36,7 @@
#include <fox/FMantaWidgets.h>
// There appear to be some #define conflicts between the FX headers and the
ones below.
-#include <Interface/RTRTInterface.h>
+#include <Interface/MantaInterface.h>
#include <UserInterface/CameraPathAutomator.h>
Modified: trunk/fox/FMantaWidgets.h
==============================================================================
--- trunk/fox/FMantaWidgets.h (original)
+++ trunk/fox/FMantaWidgets.h Thu Dec 8 14:28:52 2005
@@ -7,7 +7,7 @@
#include <fx3d.h>
#include <MantaTypes.h>
-#include <Interface/RTRTInterface.h>
+#include <Interface/MantaInterface.h>
namespace fox_manta {
@@ -20,11 +20,11 @@
template< class Arg1 >
class FMantaSetter {
protected:
- RTRTInterface *manta_interface;
+ MantaInterface *manta_interface;
public:
FMantaSetter() : manta_interface( 0 ) { };
- FMantaSetter( RTRTInterface *manta_interface_ ) :
manta_interface( manta_interface_ ) { };
+ FMantaSetter( MantaInterface *manta_interface_ ) :
manta_interface( manta_interface_ ) { };
// This method is called by a gui widget to send a manta
transaction with
// the new value.
@@ -39,7 +39,7 @@
void (Target::*pmf)(Arg1);
public:
- FMantaSet( RTRTInterface *manta_interface_, Target* ptr_,
void (Target::*pmf_)(Arg1) ) :
+ FMantaSet( MantaInterface *manta_interface_, Target* ptr_,
void (Target::*pmf_)(Arg1) ) :
FMantaSetter<Arg1>( manta_interface_ ), ptr( ptr_ ),
pmf( pmf_ ) { }
virtual void sendCallback( Arg1 &arg1 ) {
Modified: trunk/fox/FMantaWindow.h
==============================================================================
--- trunk/scenes/0.cc (original)
+++ trunk/scenes/0.cc Thu Dec 8 14:28:52 2005
@@ -4,7 +4,7 @@
#include <Core/Util/Args.h>
#include <Interface/Context.h>
#include <Interface/LightSet.h>
-#include <Interface/RTRTInterface.h>
+#include <Interface/MantaInterface.h>
#include <Interface/Scene.h>
#include <Model/AmbientLights/ArcAmbient.h>
#include <Model/Backgrounds/LinearBackground.h>
Modified: trunk/scenes/ParticleBVHTest.cc
==============================================================================
--- trunk/scenes/ParticleBVHTest.cc (original)
+++ trunk/scenes/ParticleBVHTest.cc Thu Dec 8 14:28:52 2005
@@ -4,7 +4,7 @@
#include <Core/Math/MiscMath.h>
#include <Interface/Context.h>
#include <Interface/LightSet.h>
-#include <Interface/RTRTInterface.h>
+#include <Interface/MantaInterface.h>
#include <Interface/Scene.h>
#include <Model/AmbientLights/ArcAmbient.h>
#include <Model/Backgrounds/LinearBackground.h>
Modified: trunk/scenes/acceltest.cc
==============================================================================
--- trunk/scenes/acceltest.cc (original)
+++ trunk/scenes/acceltest.cc Thu Dec 8 14:28:52 2005
@@ -3,7 +3,7 @@
#include <Core/Util/Args.h>
#include <Interface/Context.h>
#include <Interface/LightSet.h>
-#include <Interface/RTRTInterface.h>
+#include <Interface/MantaInterface.h>
#include <Interface/Scene.h>
#include <Model/AmbientLights/ArcAmbient.h>
#include <Model/Backgrounds/LinearBackground.h>
Modified: trunk/scenes/cube.cc
==============================================================================
--- trunk/scenes/cube.cc (original)
+++ trunk/scenes/cube.cc Thu Dec 8 14:28:52 2005
@@ -4,7 +4,7 @@
#include <Core/Util/Args.h>
#include <Interface/Context.h>
#include <Interface/LightSet.h>
-#include <Interface/RTRTInterface.h>
+#include <Interface/MantaInterface.h>
#include <Interface/Scene.h>
#include <Model/AmbientLights/ArcAmbient.h>
#include <Model/Backgrounds/LinearBackground.h>
Modified: trunk/scenes/objviewer.cc
==============================================================================
--- trunk/scenes/objviewer.cc (original)
+++ trunk/scenes/objviewer.cc Thu Dec 8 14:28:52 2005
@@ -7,7 +7,7 @@
#include <Interface/Context.h>
#include <Interface/LightSet.h>
-#include <Interface/RTRTInterface.h>
+#include <Interface/MantaInterface.h>
#include <Interface/Scene.h>
#include <Interface/Material.h>
Modified: trunk/scenes/primtest.cc
==============================================================================
--- trunk/scenes/primtest.cc (original)
+++ trunk/scenes/primtest.cc Thu Dec 8 14:28:52 2005
@@ -165,7 +165,7 @@
else if(material == "image")
{
Image *img = readTGA( imageName );
- matl = new Lambertian( new ImageTexture( img, 1.0, 1.0 ) );
+ matl = new Lambertian( new ImageTexture<Color>( img ) );
mapr = new UniformMapper();
}
else
@@ -176,15 +176,9 @@
for(int i=0;i<numx;i++){
for(int j=0;j<numy;j++){
int idx = j*numx+i;
-<<<<<<< .working
- double radius = (idx+1)/static_cast<double>(numx*numy)*scale/max;
- Point p((numx>1 ? i/static_cast<double>(numx-1) - 0.5 : 0.)*scale*2,
- (numy>1 ? j/static_cast<double>(numy-1) - 0.5 : 0.)*scale*2,
-=======
Real radius = (idx+1)/((numx*numy)*scale/max);
- Point p((i/static_cast<Real>(numx-1) - (Real)0.5)*scale*2,
- (j/static_cast<Real>(numy-1) - (Real)0.5)*scale*2,
->>>>>>> .merge-right.r751
+ Point p((numx>1 ? i/static_cast<Real>(numx-1) - (Real)0.5 :
0)*scale*2,
+ (numy>1 ? j/static_cast<Real>(numy-1) - (Real)0.5 :
0)*scale*2,
0);
Primitive* prim = new Sphere( matl, p, radius );
if ( mapr )
@@ -192,8 +186,6 @@
group->add( prim );
}
}
-<<<<<<< .working
-=======
} else if (primtype == "simplesuperellipsoid"){
for(int i=0;i<numx;i++){
for(int j=0;j<numy;j++){
@@ -210,18 +202,12 @@
group->add( prim );
}
}
->>>>>>> .merge-right.r751
} else if(primtype == "simplebox"){
Vector p2(scale/max, scale/max, scale/max);
for(int i=0;i<numx;i++){
for(int j=0;j<numy;j++){
-<<<<<<< .working
- Point p((numx>1 ? i/static_cast<double>(numx-1) - 0.5 : 0.)*scale*2,
- (numy>1 ? j/static_cast<double>(numy-1) - 0.5 : 0.)*scale*2,
-=======
- Point p((i/static_cast<Real>(numx-1) - (Real)0.5)*scale*2,
- (j/static_cast<Real>(numy-1) - (Real)0.5)*scale*2,
->>>>>>> .merge-right.r751
+ Point p((numx>1 ? i/static_cast<Real>(numx-1) - (Real)0.5 :
0)*scale*2,
+ (numy>1 ? j/static_cast<Real>(numy-1) - (Real)0.5 :
0)*scale*2,
0);
Primitive* prim = new Cube( matl, p-p2, p2.x()*1.156, p2.y()*1.156,
p2.z()*1.156 );
if ( mapr )
@@ -271,7 +257,7 @@
prim->setTexCoordMapper( mapr );
spinprim = prim;
} else if (primtype == "superellipsoid"){
- Primitive* prim = new SuperEllipsoid(matl, 0.5, 1.5);
+ Primitive* prim = new SuperEllipsoid(matl, Point(0, 0, 0), scale / max,
0.5, 1.5);
if ( mapr )
prim->setTexCoordMapper( mapr );
spinprim = prim;
@@ -295,21 +281,11 @@
if(arraytype == "spin"){
for(int i=0;i<numx;i++){
for(int j=0;j<numy;j++){
-<<<<<<< .working
- Vector p((numx>1 ? i/static_cast<double>(numx-1) - 0.5 :
0.)*scale*2,
- (numy>1 ? j/static_cast<double>(numy-1) - 0.5 :
0.)*scale*2,
-=======
- Vector p((i/static_cast<Real>(numx-1) - (Real)0.5)*scale*2,
- (j/static_cast<Real>(numy-1) - (Real)0.5)*scale*2,
->>>>>>> .merge-right.r751
- 0);
-<<<<<<< .working
- double a1 = i/static_cast<double>(numx)*M_PI*2;
- double a2 = j/static_cast<double>(numy)*M_PI*2;
-=======
- Real a1 = i/static_cast<Real>(numx-1)*(Real)M_PI*2;
- Real a2 = j/static_cast<Real>(numy-1)*(Real)M_PI*2;
->>>>>>> .merge-right.r751
+ Vector p((numx>1 ? i/static_cast<Real>(numx-1) - (Real)0.5 :
0)*scale*2,
+ (numy>1 ? j/static_cast<Real>(numy-1) - (Real)0.5 :
0)*scale*2,
+ 0);
+ Real a1 = i/static_cast<Real>(numx)*(Real)M_PI*2;
+ Real a2 = j/static_cast<Real>(numy)*(Real)M_PI*2;
AffineTransform t;
t.initWithIdentity();
t.rotate(Vector(0,1,0), a1);
@@ -321,13 +297,8 @@
} else if(arraytype == "shift"){
for(int i=0;i<numx;i++){
for(int j=0;j<numy;j++){
-<<<<<<< .working
- Vector p((numx>1 ? i/static_cast<double>(numx-1) - 0.5 :
0.)*scale*2,
- (numy>1 ? j/static_cast<double>(numy-1) - 0.5 :
0.)*scale*2,
-=======
- Vector p((i/static_cast<Real>(numx-1) - (Real)0.5)*scale*2,
- (j/static_cast<Real>(numy-1) - (Real)0.5)*scale*2,
->>>>>>> .merge-right.r751
+ Vector p((numx>1 ? i/static_cast<Real>(numx-1) - (Real)0.5 :
0)*scale*2,
+ (numy>1 ? j/static_cast<Real>(numy-1) - (Real)0.5 :
0)*scale*2,
0);
group->add(new InstanceT(spinprim, p));
}
@@ -335,13 +306,8 @@
} else if(arraytype == "scale"){
for(int i=0;i<numx;i++){
for(int j=0;j<numy;j++){
-<<<<<<< .working
- Vector p((numx>1 ? i/static_cast<double>(numx-1) - 0.5 :
0.)*scale*2,
- (numy>1 ? j/static_cast<double>(numy-1) - 0.5 :
0.)*scale*2,
-=======
- Vector p((i/static_cast<Real>(numx-1) - (Real)0.5)*scale*2,
- (j/static_cast<Real>(numy-1) - (Real)0.5)*scale*2,
->>>>>>> .merge-right.r751
+ Vector p((numx>1 ? i/static_cast<Real>(numx-1) - (Real)0.5 :
0)*scale*2,
+ (numy>1 ? j/static_cast<Real>(numy-1) - (Real)0.5 :
0)*scale*2,
0);
int idx = j*numx+i;
Real scale = (idx+1)/static_cast<Real>(numx*numy);
@@ -351,13 +317,8 @@
} else if(arraytype == "nuscale"){
for(int i=0;i<numx;i++){
for(int j=0;j<numy;j++){
-<<<<<<< .working
- Vector p((numx>1 ? i/static_cast<double>(numx-1) - 0.5 :
0.)*scale*2,
- (numy>1 ? j/static_cast<double>(numy-1) - 0.5 :
0.)*scale*2,
-=======
- Vector p((i/static_cast<Real>(numx-1) - (Real)0.5)*scale*2,
- (j/static_cast<Real>(numy-1) - (Real)0.5)*scale*2,
->>>>>>> .merge-right.r751
+ Vector p((numx>1 ? i/static_cast<Real>(numx-1) - (Real)0.5 :
0)*scale*2,
+ (numy>1 ? j/static_cast<Real>(numy-1) - (Real)0.5 :
0)*scale*2,
0);
Real xscale = (i+1)/static_cast<Real>(numx);
Real yscale = (j+1)/static_cast<Real>(numy);
@@ -367,21 +328,11 @@
} else if(arraytype == "spinscale"){
for(int i=0;i<numx;i++){
for(int j=0;j<numy;j++){
-<<<<<<< .working
- Vector p((numx>1 ? i/static_cast<double>(numx-1) - 0.5 :
0.)*scale*2,
- (numy>1 ? j/static_cast<double>(numy-1) - 0.5 :
0.)*scale*2,
-=======
- Vector p((i/static_cast<Real>(numx-1) - (Real)0.5)*scale*2,
- (j/static_cast<Real>(numy-1) - (Real)0.5)*scale*2,
->>>>>>> .merge-right.r751
- 0);
-<<<<<<< .working
- double a1 = i/static_cast<double>(numx)*M_PI*2;
- double a2 = j/static_cast<double>(numy)*M_PI*2;
-=======
- Real a1 = i/static_cast<Real>(numx-1)*(Real)M_PI*2;
- Real a2 = j/static_cast<Real>(numy-1)*(Real)M_PI*2;
->>>>>>> .merge-right.r751
+ Vector p((numx>1 ? i/static_cast<Real>(numx-1) - (Real)0.5 :
0)*scale*2,
+ (numy>1 ? j/static_cast<Real>(numy-1) - (Real)0.5 :
0)*scale*2,
+ 0);
+ Real a1 = i/static_cast<Real>(numx)*(Real)M_PI*2;
+ Real a2 = j/static_cast<Real>(numy)*(Real)M_PI*2;
int idx = j*numx+i;
Real scale = (idx+1)/static_cast<Real>(numx*numy);
AffineTransform t;
@@ -396,21 +347,11 @@
} else if(arraytype == "spinscale2"){
for(int i=0;i<numx;i++){
for(int j=0;j<numy;j++){
-<<<<<<< .working
- Vector p((numx>1 ? i/static_cast<double>(numx-1) - 0.5 :
0.)*scale*2,
- (numy>1 ? j/static_cast<double>(numy-1) - 0.5 :
0.)*scale*2,
-=======
- Vector p((i/static_cast<Real>(numx-1) - (Real)0.5)*scale*2,
- (j/static_cast<Real>(numy-1) - (Real)0.5)*scale*2,
->>>>>>> .merge-right.r751
- 0);
-<<<<<<< .working
- double a1 = i/static_cast<double>(numx)*M_PI*2;
- double a2 = j/static_cast<double>(numy)*M_PI*2;
-=======
- Real a1 = i/static_cast<Real>(numx-1)*(Real)M_PI*2;
- Real a2 = j/static_cast<Real>(numy-1)*(Real)M_PI*2;
->>>>>>> .merge-right.r751
+ Vector p((numx>1 ? i/static_cast<Real>(numx-1) - (Real)0.5 :
0)*scale*2,
+ (numy>1 ? j/static_cast<Real>(numy-1) - (Real)0.5 :
0)*scale*2,
+ 0);
+ Real a1 = i/static_cast<Real>(numx)*(Real)M_PI*2;
+ Real a2 = j/static_cast<Real>(numy)*(Real)M_PI*2;
int idx = j*numx+i;
Real scale = (idx+1)/static_cast<Real>(numx*numy);
AffineTransform t;
Modified: trunk/scenes/volume.cc
==============================================================================
--- trunk/scenes/volume.cc (original)
+++ trunk/scenes/volume.cc Thu Dec 8 14:28:52 2005
@@ -10,7 +10,7 @@
#include <Core/Util/Args.h>
#include <Interface/Context.h>
#include <Interface/LightSet.h>
-#include <Interface/RTRTInterface.h>
+#include <Interface/MantaInterface.h>
#include <Interface/Scene.h>
#include <Model/AmbientLights/ArcAmbient.h>
#include <Model/Backgrounds/ConstantBackground.h>
- [MANTA] r754 - in trunk: . Engine/Control Engine/Display Engine/IdleModes Interface Model/Groups Model/Materials Model/Readers Model/Readers/BART Model/Textures Readers StandAlone SwigInterface UserInterface fox scenes, sparker, 12/08/2005
Archive powered by MHonArc 2.6.16.
--- trunk/Engine/Control/RTRT.cc (original)
+++ trunk/Engine/Control/RTRT.cc Thu Dec 8 14:28:52 2005
@@ -54,12 +54,12 @@
#define RENDER_THREAD_STACKSIZE 8*1024*1024
namespace Manta {
- RTRTInterface* createRTRT()
+ MantaInterface* createManta()
{
return new RTRT();
}
- extern void registerKnownComponents(RTRTInterface* rtrt);
+ extern void registerKnownComponents(MantaInterface* rtrt);
}
RTRT::RTRT()
@@ -78,7 +78,7 @@
running=false;
animFrameState.frameNumber = 0;
animFrameState.frameTime = 0;
- timeMode = RTRTInterface::RealTime;
+ timeMode = MantaInterface::RealTime;
timeScale = 1;
frameRate = 15;
pipelineNeedsSetup = true;
@@ -127,7 +127,7 @@
callbackLock.writeLock();
// #if NOTFINISHED
- if(whence == RTRTInterface::Relative) {
+ if(whence == MantaInterface::Relative) {
frame += animFrameState.frameNumber;
}
// #endif
@@ -141,7 +141,7 @@
{
callbackLock.writeLock();
- if(whence == RTRTInterface::Relative) {
+ if(whence == MantaInterface::Relative) {
frame += animFrameState.frameNumber;
}
@@ -169,7 +169,7 @@
callbackLock.writeUnlock();
}
-void RTRT::registerTerminationCallback( CallbackBase_1Data< RTRTInterface *>
*cb ) {
+void RTRT::registerTerminationCallback( CallbackBase_1Data< MantaInterface
*> *cb ) {
callbackLock.writeLock();
terminationCallbacks.push_back(cb);
callbackLock.writeUnlock();
@@ -520,7 +520,7 @@
TCallbackMapType::iterator iter = terminationCallbacks.begin();
while (iter != terminationCallbacks.end()) {
// Invoke the callback and pass in the RTRTInterface.
(*iter)->call( this );
++iter;
}
@@ -655,9 +655,9 @@
imageDisplays[name] = fun;
}
-RTRTInterface::listType RTRT::listImageDisplays() const
+MantaInterface::listType RTRT::listImageDisplays() const
{
- RTRTInterface::listType list;
+ MantaInterface::listType list;
for(ImageDisplayMapType::const_iterator iter = imageDisplays.begin();
iter != imageDisplays.end(); iter++)
list.push_back(iter->first);
@@ -823,9 +823,9 @@
imageCreators[name] = fun;
}
-RTRTInterface::listType RTRT::listImageTypes() const
+MantaInterface::listType RTRT::listImageTypes() const
{
- RTRTInterface::listType list;
+ MantaInterface::listType list;
for(ImageCreatorMapType::const_iterator iter = imageCreators.begin();
iter != imageCreators.end(); iter++)
list.push_back(iter->first);
@@ -857,9 +857,9 @@
imageTraversers[name] = fun;
}
-RTRTInterface::listType RTRT::listImageTraversers() const
+MantaInterface::listType RTRT::listImageTraversers() const
{
- RTRTInterface::listType list;
+ MantaInterface::listType list;
for(ImageTraverserMapType::const_iterator iter = imageTraversers.begin();
iter != imageTraversers.end(); iter++)
list.push_back(iter->first);
@@ -887,9 +887,9 @@
loadBalancers[name] = fun;
}
-RTRTInterface::listType RTRT::listLoadBalancers() const
+MantaInterface::listType RTRT::listLoadBalancers() const
{
- RTRTInterface::listType list;
+ MantaInterface::listType list;
for(LoadBalancerMapType::const_iterator iter = loadBalancers.begin();
iter != loadBalancers.end(); iter++)
list.push_back(iter->first);
@@ -933,9 +933,9 @@
pixelSamplers[name] = fun;
}
-RTRTInterface::listType RTRT::listPixelSamplers() const
+MantaInterface::listType RTRT::listPixelSamplers() const
{
- RTRTInterface::listType list;
+ MantaInterface::listType list;
for(PixelSamplerMapType::const_iterator iter = pixelSamplers.begin();
iter != pixelSamplers.end(); iter++)
list.push_back(iter->first);
@@ -962,9 +962,9 @@
renderers[name] = fun;
}
-RTRTInterface::listType RTRT::listRenderers() const
+MantaInterface::listType RTRT::listRenderers() const
{
- RTRTInterface::listType list;
+ MantaInterface::listType list;
for(RendererMapType::const_iterator iter = renderers.begin();
iter != renderers.end(); iter++)
list.push_back(iter->first);
@@ -991,9 +991,9 @@
idleModes[name] = fun;
}
-RTRTInterface::listType RTRT::listIdleModes() const
+MantaInterface::listType RTRT::listIdleModes() const
{
- RTRTInterface::listType list;
+ MantaInterface::listType list;
for(IdleModeMapType::const_iterator iter = idleModes.begin();
iter != idleModes.end(); iter++)
list.push_back(iter->first);
@@ -1020,9 +1020,9 @@
shadowAlgorithms[name] = fun;
}
-RTRTInterface::listType RTRT::listShadowAlgorithms() const
+MantaInterface::listType RTRT::listShadowAlgorithms() const
{
- RTRTInterface::listType list;
+ MantaInterface::listType list;
for(ShadowAlgorithmMapType::const_iterator iter = shadowAlgorithms.begin();
iter != shadowAlgorithms.end(); iter++)
list.push_back(iter->first);
@@ -1049,9 +1049,9 @@
cameras[name] = fun;
}
-RTRTInterface::listType RTRT::listCameras() const
+MantaInterface::listType RTRT::listCameras() const
{
- RTRTInterface::listType list;
+ MantaInterface::listType list;
for(CameraMapType::const_iterator iter = cameras.begin();
iter != cameras.end(); iter++)
list.push_back(iter->first);
@@ -1143,9 +1143,9 @@
groups[name] = creator;
}
-RTRTInterface::listType RTRT::listGroups() const
+MantaInterface::listType RTRT::listGroups() const
{
- RTRTInterface::listType list;
+ MantaInterface::listType list;
for(GroupMapType::const_iterator iter = groups.begin();
iter != groups.end(); iter++)
list.push_back(iter->first);
@@ -1218,9 +1218,9 @@
userInterfaces[name] = creator;
}
-RTRTInterface::listType RTRT::listUserInterfaces() const
+MantaInterface::listType RTRT::listUserInterfaces() const
{
- RTRTInterface::listType list;
+ MantaInterface::listType list;
for(UserInterfaceMapType::const_iterator iter = userInterfaces.begin();
iter != userInterfaces.end(); iter++)
list.push_back(iter->first);
@@ -520,7 +520,7 @@
TCallbackMapType::iterator iter = terminationCallbacks.begin();
while (iter != terminationCallbacks.end()) {
- // Invoke the callback and pass in the RTRTInterface.
+ // Invoke the callback and pass in the MantaInterface.
(*iter)->call( this );
Modified: trunk/Engine/Control/RTRT.h
==============================================================================
--- trunk/fox/FMantaWindow.h (original)
+++ trunk/fox/FMantaWindow.h Thu Dec 8 14:28:52 2005
@@ -4,7 +4,7 @@
#include <fx.h>
#include <fx3d.h>
-#include <Interface/RTRTInterface.h>
+#include <Interface/MantaInterface.h>
#include <Engine/Display/GLXImageDisplay.h>
#include <fox/FMantaImageFrame.h>
@@ -23,7 +23,7 @@
class FMantaRecorderDialog;
// This is the main window for the Fox application.
// this class will have a pointer to the RTRTInterface (manta interface)
// it will also be responsible for initializing manta as well as the rest
of
// the application.
class FMantaWindow : public FXMainWindow {
@@ -31,7 +31,7 @@
private:
// Interface to the manta rendering library.
- RTRTInterface *manta_interface;
+ MantaInterface *manta_interface;
// Other manta pipeline components which the application "controls"
// (Transactions must be sent through manta in order to manipulate
@@ -187,11 +187,11 @@
long onCoordSystemUp ( FXObject *sender, FXSelector key, void *data );
// Accessors.
- void setMantaInterface( RTRTInterface *manta_interface_, int
manta_channel_ ) {
+ void setMantaInterface( MantaInterface *manta_interface_, int
manta_channel_ ) {
manta_interface = manta_interface_; manta_frame->setMantaInterface(
manta_interface_, manta_channel_ ); };
void setNavigator( FMantaNavigator *navigator_ ) {
manta_frame->setNavigator( navigator_ ); };
- RTRTInterface *getMantaInterface() { return manta_interface; };
+ MantaInterface *getMantaInterface() { return manta_interface; };
FMantaImageFrame *getMantaFrame() { return manta_frame; };
@@ -236,7 +236,7 @@
void mantaUnHideAll();
// This methid is called by manta when the last rendering thread exits.
- void mantaTerminate( RTRTInterface *manta_interface );
+ void mantaTerminate( MantaInterface *manta_interface );
void mantaSetCameraUp( int up );
};
Modified: trunk/scenes/0.cc
@@ -23,7 +23,7 @@
class FMantaRecorderDialog;
// This is the main window for the Fox application.
- // this class will have a pointer to the RTRTInterface (manta interface)
+ // this class will have a pointer to the MantaInterface (manta interface)
// it will also be responsible for initializing manta as well as the rest
of
==============================================================================